@@ -268,32 +268,38 @@ sub _html_head
 	{
 	    my $path = $DebianDoc_SGML::Format::Driver::opt_1
 		? "#$id" : "$prefix$id$content$extension";
+	    my $title = "$chapter_num{ $id } $chapter_title{ $id }";
+	    $title =~ s/<[^>]*>//g;
 	    output( "<link"
 		    . " href=\"$path\""
 		    . ( $chapter_type{ $id } eq 'chapter'
 			? " rel=\"chapter\""
 			: " rel=\"appendix\"" )
-		    . " title=\"$chapter_num{ $id } $chapter_title{ $id }\""
+		    . " title=\"$title\""
 		    . ">\n" );
 	}
 	foreach my $id ( @section_id )
 	{
 	    my $path = "$prefix$section_chapter_id{ $id }$content$extension"
 		if ! $DebianDoc_SGML::Format::Driver::opt_1;
+	    my $title = "$section_num{ $id } $section_title{ $id }";
+	    $title =~ s/<[^>]*>//g;
 	    output( "<link"
 		    . " href=\"$path#$id\""
 		    . " rel=\"section\""
-		    . " title=\"$section_num{ $id } $section_title{ $id }\""
+		    . " title=\"$title\""
 		    . ">\n" );
 	}
 	foreach my $id ( @subsection_id )
 	{
 	    my $path = "$prefix$subsection_chapter_id{ $id }$content$extension"
 		if ! $DebianDoc_SGML::Format::Driver::opt_1;
+	    my $title = "$subsection_num{ $id } $subsection_title{ $id }";
+	    $title =~ s/<[^>]*>//g;
 	    output( "<link"
 		    . " href=\"$path#$id\""
 		    . " rel=\"subsection\""
-		    . " title=\"$subsection_num{ $id } $subsection_title{ $id }\""
+		    . " title=\"$title\""
 		    . ">\n" );
 	}
     }
