@@ -68,17 +68,30 @@ if ( $DebianDoc_SGML::Format::Driver::opt_b =~ m,/, )
     $basename = dirname( $DebianDoc_SGML::Format::Driver::opt_b );
     $prefix = basename( $DebianDoc_SGML::Format::Driver::opt_b ) . '-';
 }
-my $topname = length( $DebianDoc_SGML::Format::Driver::opt_t )
-    ? $DebianDoc_SGML::Format::Driver::opt_t : 'index';
+my $topname = '';
+if ( $DebianDoc_SGML::Format::Driver::opt_1 )
+{
+    $topname = length( $DebianDoc_SGML::Format::Driver::opt_t )
+        ? $DebianDoc_SGML::Format::Driver::opt_t : $basename;
+}
+else
+{
+    $topname = length( $DebianDoc_SGML::Format::Driver::opt_t )
+        ? $DebianDoc_SGML::Format::Driver::opt_t : 'index';
+}
 my $extension = length( $DebianDoc_SGML::Format::Driver::opt_e )
-    ? ".$DebianDoc_SGML::Format::Driver::opt_e" : '.xml';
+    ? ".$DebianDoc_SGML::Format::Driver::opt_e" : '.dbk';
 my $single = $DebianDoc_SGML::Format::Driver::opt_1;
 
 ## ----------------------------------------------------------------------
 ## directory definition and creation
-my $directory = "$basename$extension";
--d "$directory" || mkdir( "$directory", 0777 )
-    || die "cannot make directory \`$directory': $!\n";
+my $directory = '.';
+if ( ! $DebianDoc_SGML::Format::Driver::opt_1 )
+{
+    $directory = "$basename$extension";
+    -d "$directory" || mkdir( "$directory", 0777 )
+       || die "cannot make directory \`$directory': $!\n";
+}
 
 ## ----------------------------------------------------------------------
 ## layout definition
@@ -153,6 +166,8 @@ sub _output_end_book
 	    my $file = "$prefix$idx$content$extension";
 	    push_output( 'file',
 			 File::Spec->catfile( "$directory", "$file" ) );
+    	    output( "<?xml version='1.0'?>\n" );
+    	    output( "<!-- -*- DocBook -*- -->\n" );
 	}
 	output( $chapter{ $chapter_id } );
 	if ( ! $DebianDoc_SGML::Format::Driver::opt_1 )
@@ -171,27 +186,11 @@ sub _html_head
 {
     output( "<?xml version='1.0'?>\n" );
     output( "<!-- -*- DocBook -*- -->\n" );
-    output( "<!DOCTYPE book PUBLIC \"-//OASIS//DTD DocBook XML V4.4//EN\"\n" );
-    output( "    \"http://www.oasis-open.org/docbook/xml/4.4/docbookx.dtd\" [\n" );
-#    output( "<!ENTITY % sgml.features \"IGNORE\">\n" );
-#    output( "<!ENTITY % xml.features  \"INCLUDE\">\n" );
-    if ( ! $DebianDoc_SGML::Format::Driver::opt_1 )
-    {
-        output( "\n" );
-	output( "<!-- subdoc list start -->\n" );
-	foreach my $id ( @chapter_id )
-	{
-	    my $idx = $id;
-	    $idx =~ s/^ch-//;
-	    $idx =~ s/^ap-//;
-	    $idx =~ s/_/-/g;
-	    $idx =~ s/ /-/g;
-    	    output( "<!ENTITY " . $idx . $_[0] . " SYSTEM \"" . $idx . $_[0] . "\" >\n" );
-	}
-	output( "<!-- subdoc list end -->\n" );
-	output( "\n" );
-    }
-    output( "]>\n" );
+    output( "<!DOCTYPE book PUBLIC \"-//OASIS//DTD DocBook XML V4.5//EN\"\n" );
+    output( "    \"http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd\" [\n" );
+    output( "<!-- Include entity definition file by uncommenting the following -->\n" );
+    output( '<!-- <!ENTITY % versiondata SYSTEM "version.ent"> %versiondata;   -->' );
+    output( "\n]>\n" );
     output( "\n" );
 
     my $locale = $DebianDoc_SGML::Format::Driver::locale;
@@ -200,30 +199,43 @@ sub _html_head
     $language_tag = 'en' if $language_tag eq undef;
 
     output( "<book lang=\"$language_tag\">\n" );
-    output( "<!-- This may be encoded in iso-8859-1 for western languages. -->\n" );
-    output( "<!-- This may be encoded in euc-jp for Japanese. -->\n" );
-    output( "<!-- Make sure to convert files to UTF-8 encoding after conversion. -->\n" );
+    output( "<!-- This is UTF-8 encoded. -->\n" );
     output( "\n" );
     output( "<title>$title</title>\n" );
     output( "\n" );
     output( "<bookinfo>\n" );
     output( "\n" );
+    output( "<authorgroup>\n" );
     if ( $#author >= 0 )
     {
 	foreach ( @author )
 	{
-	    my $firstname ;
-	    my $surname ;
+	    my $personname ;
 	    my $emailname ;
-	    $firstname = $_ ;
-	    $surname = $_ ;
+	    $personname = $_ ;
 	    $emailname = $_ ;
-	    # If you hav patch to middle name, please send me
-	    $firstname =~ s/ .*//;
-	    $surname =~ s/[^ ]+[ ]*// ;
-	    $surname =~ s/[ ]*<email>.*$// ;
-	    $emailname =~ s/.*<email>/<email>/ ;
-	    output( "<author> <firstname>$firstname</firstname> <surname>$surname</surname> $emailname </author>\n" );
+            if ( $emailname =~ m/^.*<email>.*<\/email>.*$/ )
+            {
+	        $emailname =~ s/^.*<email>(.*)<\/email>.*$/$1/ ;
+            }
+            else
+            {
+                $emailname = '';
+            }
+	    $personname =~ s/<email>.*<\/email>// ;
+	    # trim spacies and tabs
+	    $personname =~ s/^[ 	]*// ;
+	    $personname =~ s/[ 	]*$// ;
+	    $emailname =~ s/^[ 	]*// ;
+	    $emailname =~ s/[ 	]*$// ;
+            if ( $emailname )
+            {
+	        output( "<author><personname>$personname</personname><email>$emailname</email></author>\n" );
+            }
+            else
+            {
+	        output( "<author><personname>$personname</personname></author>\n" );
+            }
 	}
 	output( "\n" );
     }
@@ -231,21 +243,36 @@ sub _html_head
     {
 	foreach ( @translator )
 	{
-	    my $firstname ;
-	    my $surname ;
+	    my $personname ;
 	    my $emailname ;
-	    $firstname = $_ ;
-	    $surname = $_ ;
+	    $personname = $_ ;
 	    $emailname = $_ ;
-	    # If you hav patch to middle name, please send me
-	    $firstname =~ s/ .*//;
-	    $surname =~ s/[^ ]+[ ]*// ;
-	    $surname =~ s/[ ]*<email>.*$// ;
-	    $emailname =~ s/.*<email>/<email>/ ;
-	    output( "<author> <firstname>$firstname</firstname> <surname>$surname</surname> $emailname </author>\n" );
+            if ( $emailname =~ m/^.*<email>.*<\/email>.*$/ )
+            {
+	        $emailname =~ s/^.*<email>(.*)<\/email>.*$/$1/ ;
+            }
+            else
+            {
+                $emailname = '';
+            }
+	    $personname =~ s/<email>.*<\/email>// ;
+	    # trim spacies and tabs
+	    $personname =~ s/^[ 	]*// ;
+	    $personname =~ s/[ 	]*$// ;
+	    $emailname =~ s/^[ 	]*// ;
+	    $emailname =~ s/[ 	]*$// ;
+            if ( $emailname )
+            {
+	        output( "<othercredit role=\"translator\"><personname>$personname</personname><contrib><!-- [[language]] translation --></contrib><email>$emailname</email></othercredit>\n" );
+            }
+            else
+            {
+	        output( "<othercredit role=\"translator\"><personname>$personname</personname><contrib><!-- [[language]] translation --></contrib></othercredit>\n" );
+            }
 	}
 	output( "\n" );
     }
+    output( "</authorgroup>\n" );
     output( "<releaseinfo>$version</releaseinfo>\n" );
     output( "\n" );
     output( "<pubdate>" );
@@ -263,36 +290,39 @@ sub _html_head
     if ( length( $copyright ) )
     {
         output( "\n" );
-        output( "<copyright>\n" );
 	foreach my $copyline ( @copyrightsummary )
 	{
 	    my $year;
+            $copyline =~ s/copyright//i;
+            $copyline =~ s/©//;
 	    $year = $copyline;
-	    $year =~ s/[^0-9]//g;
+	    $year =~ s/[A-Za-z<].*$//;
+	    $year =~ s/^[	 ]*//;
+	    $year =~ s/[	 ]*$//;
+            output( "<copyright>" );
             output( "<year>" );
-            output( "<!-- put year -->$year" );
-            output( "</year>\n" );
+            output( "$year" );
+            output( "</year>" );
             output( "<holder>" );
-            output( "<!-- put name -->" );
-	    $copyline =~ s/&copy;// ;
+	    $copyline =~ s/^[^A-Za-z<]*([A-Za-z<].*)$/$1/g;
 	    $copyline =~ s/<email>// ;
 	    $copyline =~ s/<\/email>// ;
+	    $copyline =~ s/^[ 	]*// ;
+	    $copyline =~ s/[ 	]*$// ;
             output( $copyline );
-            output( "</holder>\n" );
+            output( "</holder>" );
+            output( "</copyright>\n" );
 	}
-        output( "</copyright>\n" );
         output( "<legalnotice>\n" );
 	output( $copyright );
         output( "</legalnotice>\n" );
     }
     output( "\n" );
-    output( "<!-- toc -->\n" );
-    output( "\n" );
     output( "</bookinfo>\n" );
     output( "\n" );
     if ( ! $DebianDoc_SGML::Format::Driver::opt_1 )
     {
-	output( "<!-- subdoc list start -->\n" );
+	output( "<!-- XInclude list start -->\n" );
 	foreach my $id ( @chapter_id )
 	{
 	    my $idx = $id;
@@ -300,9 +330,9 @@ sub _html_head
 	    $idx =~ s/^ap-//;
 	    $idx =~ s/_/-/g;
 	    $idx =~ s/ /-/g;
-    	    output( "\&" . $idx . $_[0] . ";\n" );
+    	    output( "<xi:include href=\"" . $idx . $_[0] . "\" xmlns:xi=\"http://www.w3.org/2003/XInclude\"/>\n" );
 	}
-	output( "<!-- subdoc list end -->\n" );
+	output( "<!-- XInclude list end -->\n" );
 	output( "\n" );
     }
     output( "\n" );
@@ -421,28 +451,58 @@ sub _output_appendix
 }
 sub _output_sect
 {
-#    output( "</sect1>\n\n" );
-    output( "</sect>\n\n" );
+	if ( $DebianDoc_SGML::Format::Driver::opt_S )
+	{
+	    output( "</sect1>\n\n" );
+	}
+	else
+	{
+	    output( "</section>\n\n" );
+	}
 }
 sub _output_sect1
 {
-#    output( "</sect2>\n\n" );
-    output( "</sect>\n\n" );
+	if ( $DebianDoc_SGML::Format::Driver::opt_S )
+	{
+	    output( "</sect2>\n\n" );
+	}
+	else
+	{
+	    output( "</section>\n\n" );
+	}
 }
 sub _output_sect2
 {
-#    output( "</sect3>\n\n" );
-    output( "</sect>\n\n" );
+	if ( $DebianDoc_SGML::Format::Driver::opt_S )
+	{
+	    output( "</sect3>\n\n" );
+	}
+	else
+	{
+	    output( "</section>\n\n" );
+	}
 }
 sub _output_sect3
 {
-#    output( "</sect4>\n\n" );
-    output( "</sect>\n\n" );
+	if ( $DebianDoc_SGML::Format::Driver::opt_S )
+	{
+	    output( "</sect4>\n\n" );
+	}
+	else
+	{
+	    output( "</section>\n\n" );
+	}
 }
 sub _output_sect4
 {
-#    output( "</sect5>\n\n" );
-    output( "</sect>\n\n" );
+	if ( $DebianDoc_SGML::Format::Driver::opt_S )
+	{
+	    output( "</sect5>\n\n" );
+	}
+	else
+	{
+	    output( "</section>\n\n" );
+	}
 }
 sub _output_heading
 {
@@ -477,8 +537,14 @@ sub _output_heading
 	$idx =~ s/^s-//;
 	$idx =~ s/_/-/g;
 	$idx =~ s/ /-/g;
-#	output( "<sect$xmlsectid id=\"$idx\">" );
-	output( "<sect id=\"$idx\">" );
+	if ( $DebianDoc_SGML::Format::Driver::opt_S )
+	{
+	    output( "<sect$xmlsectid id=\"$idx\">" );
+	}
+	else
+	{
+	    output( "<section id=\"$idx\">" );
+	}
 	if ( length( $_[0] ) )
 	{
             output( "<title>" );
@@ -648,7 +714,7 @@ sub _output_qref
     $idx =~ s/^s-//;
     $idx =~ s/_/-/g;
     $idx =~ s/ /-/g;
-    output( "<link linkend=\"$idx\">$_[0]</link>\n" );
+    output( "<link linkend=\"$idx\">$_[0]</link>" );
 }
 
 ## ----------------------------------------------------------------------
@@ -662,11 +728,11 @@ sub _output_ref
     $idx =~ s/^s-//;
     $idx =~ s/_/-/g;
     $idx =~ s/ /-/g;
-    output( "<xref linkend=\"$idx\"/>\n" );
+    output( "<xref linkend=\"$idx\"/>" );
 }
 sub _output_manref
 {
-    output( "<citerefentry>\n<refentrytitle>$_[0]</refentrytitle>\n<manvolnum>$_[1]</manvolnum>\n</citerefentry>" );
+    output( "<citerefentry><refentrytitle>$_[0]</refentrytitle><manvolnum>$_[1]</manvolnum></citerefentry>" );
 }
 sub _output_email
 {
@@ -687,7 +753,7 @@ sub _output_email
 sub _output_ftpsite
 {
     my $url = URI->new( $_[0] );
-    output( "<ulink url=\"$url\">$url</ulink>" );
+    output( "<ulink url=\"ftp://$url\">ftp://$url</ulink>" );
 }
 sub _output_ftppath
 {
@@ -696,7 +762,7 @@ sub _output_ftppath
 sub _output_httpsite
 {
     my $url = URI->new( $_[0] );
-    output( "<httpsite>$url</httpsite>" );
+    output( "<ulink url=\"http://$url\">http://$url</ulink>" );
 }
 sub _output_httppath
 {
@@ -704,11 +770,11 @@ sub _output_httppath
 }
 sub _output_url
 {
-#    my $url = URI->new( $_[0] );
-#    $_[1] = $_[0] if $_[1] eq "";
-    output( "<ulink url=\"" );
+    my $url = URI->new( $_[0] );
+    $_[1] = $_[0] if $_[1] eq "";
+    output( "<ulink url=\"$url\">" );
     _cdata( $_[1] );
-    output( "\">$_[1]</ulink>" );
+    output( "</ulink>" );
 }
 
 ## ----------------------------------------------------------------------
@@ -718,10 +784,6 @@ sub _cdata
 {
     ( $_ ) = @_;
 
-    # special characters
-    # do not replace it
-    s/([<>&\"])/$cdata{ $1 }/g;
-
     # SDATA
     s/\\\|(\[\w+\s*\])\\\|/$sdata{ $1 }/g;
 
